@@ -28,10 +28,10 @@ from vdsm import response
 from vdsm import utils
 from vdsm import vdscli
 from vdsm import jsonrpcvdscli
-from vdsm import sslutils
 from vdsm.compat import pickle
 from vdsm.config import config
 from vdsm.define import NORMAL, Mbytes
+from vdsm.sslcompat import sslutils
 from yajsonrpc import \
     JsonRpcNoResponseError, \
     JsonRpcBindingsError
